import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';
import 'package:namer_app/bug/addbug.dart';
import 'package:namer_app/platform/addplatform.dart';
import 'package:namer_app/bug/editbug.dart';
import 'package:namer_app/platform/editplatform.dart';
import 'package:namer_app/user/edituser.dart';
import 'package:namer_app/footer.dart';
import 'package:namer_app/header.dart';
import 'package:namer_app/bug/listbug.dart';
import 'package:namer_app/bug/listcomment.dart';
import 'package:namer_app/platform/listmember.dart';
import 'package:namer_app/platform/listplatform.dart';
import 'package:namer_app/listtable.dart';
import 'package:namer_app/user/listuser.dart';
import 'package:namer_app/login.dart';
import 'package:flutter/rendering.dart';
import 'package:namer_app/user/signup.dart';


void main() {
  runApp(MyApp());
}

final _router = GoRouter(
  routes: [
    GoRoute(path: '/', builder: (context, state) => MyHomePage(), routes: [
      GoRoute(path: 'login', builder: (context, state) => LoginPage(), routes: [
        GoRoute(
            path: 'bug',
            builder: (context, state) => ListBugPage(),
            routes: [
              GoRoute(
                path: 'comment',
                builder: (context, state) => ListCommentPage(),
              ),
              GoRoute(
                path: 'editbug',
                builder: (context, state) => EditBugPage(),
              )
            ])
      ]),
      GoRoute(
          path: 'signup',
          builder: (context, state) => SignupPage(),
          routes: [
            GoRoute(
                path: 'listuser',
                builder: (context, state) => ListUserPage(),
                routes: [
                  GoRoute(
                    path: 'edit',
                    builder: (context, state) => EditUserPage(),
                  )
                ])
          ]),
      GoRoute(
        path: 'maintenance',
        builder: (context, state) => ListTablePage(),
      ),
      GoRoute(
          path: 'listplatform',
          builder: (context, state) => ListPlatformPage(),
          routes: [
            GoRoute(
              path: 'listmember',
              builder: (context, state) => ListMemberPage(),
            ),
            GoRoute(
              path: 'editplatform',
              builder: (context, state) => EditPlatformPage(),
            )
          ]),
      GoRoute(
        path: 'addbug',
        builder: (context, state) => AddBugPage(),
      ),
      GoRoute(
        path: 'addplatform',
        builder: (context, state) => AddPlatformPage(),
      ),
    ]),
  ],
);

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp.router(
      debugShowCheckedModeBanner: false,
      title: 'Bug Listing',
      routerConfig: _router,
    );
  }
}

class MyHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    debugPaintSizeEnabled = false;
    return Scaffold(
        appBar: CustomAppbar(),
        body: Container(
          decoration: BoxDecoration(color: Colors.black.withOpacity(0.6)),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: [
              Expanded(
                child: Center(
                    child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Text(
                      'Welcome to Bug Tracker',
                      style: TextStyle(
                          color: Colors.white,
                          fontSize: 40,
                          fontWeight: FontWeight.bold),
                    ),
                  ],
                )),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: Text(
                  'Track, manage, and resolve bugs efficiently',
                  style: TextStyle(color: Colors.white, fontSize: 16),
                ),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 10),
                    child: ElevatedButton(
                      onPressed: () => context.go('/signup'),
                      style: ElevatedButton.styleFrom(
                          side: BorderSide(color: Colors.white),
                          backgroundColor: Colors.transparent),
                      child: Text(
                        'Sign Up',
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 10),
                    child: ElevatedButton(
                      onPressed: () => context.go('/login'),
                      style: ElevatedButton.styleFrom(
                        backgroundColor: Colors.black,
                      ),
                      child: Text(
                        'Login',
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  ),
                ],
              ),
              Expanded(child: Container())
            ],
          ),
        ),
        bottomNavigationBar: Footer());
  }
}
